@@ -4,7 +4,7 @@ from .image import *
 from .database import *
 from .update import *
 
-from nonebot import on_command
+from nonebot import on_command, logger
 from nonebot.plugin import PluginMetadata
 import httpx
 
@@ -16,11 +16,16 @@ init_db = on_command("更新方舟数据库")
 @update_game_resource.handle()
 async def _():
     await update_game_resource.send("开始更新游戏素材……")
-    async with httpx.AsyncClient() as client:
-        await ArknightsGameData(client).download_files()
-        await ArknightsDB.init_data()
-        await ArknightsGameImage(client).download_files()
-    await update_game_resource.finish("游戏数据更新完成！")
+    try:
+        async with httpx.AsyncClient() as client:
+            await ArknightsGameData(client).download_files()
+            await ArknightsDB.init_data()
+            await ArknightsGameImage(client).download_files()
+    except httpx.ConnectError as e:
+        logger.warning("下载方舟额外素材出错，请修改代理或重试")
+        await update_game_resource.finish("下载方舟额外素材出错，请修改代理或重试")
+    else:
+        await update_game_resource.finish("游戏数据更新完成！")
 
 
 @init_db.handle()
